%global _hardened_build 1
# These are rpm macros and are 0 or 1
%global with_efence 0
%global with_development 0
%global with_cavstests 0
# Libreswan config options
%global libreswan_config \\\
    FINALLIBEXECDIR=%{_libexecdir}/ipsec \\\
    FINALMANDIR=%{_mandir} \\\
    INC_RCDEFAULT=%{_initrddir} \\\
    INC_USRLOCAL=%{_prefix} \\\
    INITSYSTEM=systemd \\\
    USE_DNSSEC=true \\\
    USE_FIPSCHECK=false \\\
    USE_LABELED_IPSEC=true \\\
    USE_LDAP=true \\\
    USE_LIBCAP_NG=true \\\
    USE_LIBCURL=true \\\
    USE_LINUX_AUDIT=true \\\
    USE_NM=true \\\
    USE_SECCOMP=true \\\
    USE_XAUTHPAM=true \\\
%{nil}

Name: libreswan
Summary: IPsec implementation with IKEv1 and IKEv2 keying protocols
Group:   System/Servers
# version is generated in the release script
Version: 4.2
Release: %mkrel 1
License: GPLv2
Url: https://libreswan.org/
Source0: https://download.libreswan.org/%{?prever:development/}%{name}-%{version}%{?prever}.tar.gz
%if 0%{with_cavstests}
Source1: https://download.libreswan.org/cavs/ikev1_dsa.fax.bz2
Source2: https://download.libreswan.org/cavs/ikev1_psk.fax.bz2
Source3: https://download.libreswan.org/cavs/ikev2.fax.bz2
%endif
Source4: libreswan-tmpfiles.conf

Requires(post): bash
Requires(post): coreutils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Conflicts: openswan < %{version}-%{release}
Obsoletes: openswan < %{version}-%{release}
Provides: openswan = %{version}-%{release}
Provides: openswan-doc = %{version}-%{release}

BuildRequires: pkgconfig
BuildRequires: hostname
BuildRequires: hostname
BuildRequires: bison
BuildRequires: flex
BuildRequires: systemd-devel
BuildRequires: nss-devel >= 3.16.1
BuildRequires: nspr-devel
BuildRequires: pam-devel
BuildRequires: libevent-devel
BuildRequires: unbound-devel >= 1.6.0-6
BuildRequires: ldns-devel
BuildRequires: libseccomp-devel
BuildRequires: libselinux-devel
BuildRequires: audit-libs-devel
BuildRequires: libcap-ng-devel
BuildRequires: openldap-devel
BuildRequires: curl-devel
%if 0%{with_efence}
BuildRequires: ElectricFence
%endif
BuildRequires: xmlto

Requires: nss
Requires: iproute2 >= 2.6.8
Requires: unbound >= 1.6.6
Requires: policycoreutils

%description
Libreswan is a free implementation of IPsec & IKE for Linux.  IPsec is
the Internet Protocol Security and uses strong cryptography to provide
both authentication and encryption services.  These services allow you
to build secure tunnels through untrusted networks.  Everything passing
through the untrusted net is encrypted by the ipsec gateway machine and
decrypted by the gateway at the other end of the tunnel.  The resulting
tunnel is a virtual private network or VPN.

This package contains the daemons and userland tools for setting up
Libreswan. To build KLIPS, see the kmod-libreswan.spec file.

Libreswan also supports IKEv2 (RFC4309) and Secure Labeling

Libreswan is based on Openswan-2.6.38 which in turn is based on FreeS/WAN-2.04

%prep
%autosetup -p1
# Fedora should really figure this versioning out itself, not burden upstream
sed -i "s:/usr/bin/python:%{__python3}:" programs/verify/verify.in
sed -i "s:/usr/bin/python:%{__python3}:" programs/show/show.in
sed -i "s:/usr/bin/python:%{__python3}:" testing/pluto/ikev1-01-fuzzer/cve-2015-3204.py
sed -i "s:/usr/bin/python:%{__python3}:" testing/pluto/ikev2-15-fuzzer/send_bad_packets.py
sed -i "s:/usr/bin/python:%{__python3}:" testing/x509/dist_certs.py
sed -i "s:/usr/bin/python:%{__python3}:" programs/_unbound-hook/_unbound-hook.in
# enable crypto-policies support
sed -i "s:#[ ]*include \(.*\)\(/crypto-policies/back-ends/libreswan.config\)$:include \1\2:" configs/ipsec.conf.in
# Restore -DALLOW_MICROSOFT_BAD_PROPOSAL for L2TP/IPsec
 sed -i "s/-pthread$/-DALLOW_MICROSOFT_BAD_PROPOSAL -pthread/" mk/config.mk
# linking to freebl is no longer needed
sed -i "s/-lfreebl //" mk/config.mk

%build
%serverbuild
%if 0%{with_efence}
%global efence "-lefence"
%endif

#796683: -fno-strict-aliasing
%make_build \
%if 0%{with_development}
    USERCOMPILE="-g -DGCC_LINT %(echo %{optflags} | sed -e s/-O[0-9]*/ /) %{?efence} -fPIE -pie -fno-strict-aliasing -Wformat-nonliteral -Wformat-security" \
%else
    USERCOMPILE="-g -DGCC_LINT %{optflags} %{?efence} -fPIE -pie -fno-strict-aliasing -Wformat-nonliteral -Wformat-security" \
%endif
    USERLINK="-g -pie -Wl,-z,relro,-z,now %{?efence}" \
    %{libreswan_config} \
    programs
FS=$(pwd)

%install
%make_install \
    DESTDIR=%{buildroot} \
    %{libreswan_config}

FS=$(pwd)
rm -rf %{buildroot}/usr/share/doc/libreswan

install -d -m 0700 %{buildroot}%{_rundir}/pluto
# used when setting --perpeerlog without --perpeerlogbase
install -d -m 0700 %{buildroot}%{_localstatedir}/log/pluto/peer
install -d %{buildroot}%{_sbindir}

install -d %{buildroot}%{_sysconfdir}/sysctl.d
install -m 0644 packaging/fedora/libreswan-sysctl.conf \
    %{buildroot}%{_sysconfdir}/sysctl.d/50-libreswan.conf

echo "include %{_sysconfdir}/ipsec.d/*.secrets" \
    > %{buildroot}%{_sysconfdir}/ipsec.secrets
rm -fr %{buildroot}%{_sysconfdir}/rc.d/rc*

# Install tmpfiles
install -d %{buildroot}%{_tmpfilesdir}
install -D -p -m 644 %{S:4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%if 0%{with_cavstests}
%check
# There is an elaborate upstream testing infrastructure which we do not
# run here - it takes hours and uses kvm
# We only run the CAVS tests.
cp %{SOURCE1} %{SOURCE2} %{SOURCE3} .
bunzip2 *.fax.bz2

# work around for older xen based machines
export NSS_DISABLE_HW_GCM=1

: starting CAVS test for IKEv2
%{buildroot}%{_libexecdir}/ipsec/cavp -v2 ikev2.fax | \
    diff -u ikev2.fax - > /dev/null
: starting CAVS test for IKEv1 RSASIG
%{buildroot}%{_libexecdir}/ipsec/cavp -v1dsa ikev1_dsa.fax | \
    diff -u ikev1_dsa.fax - > /dev/null
: starting CAVS test for IKEv1 PSK
%{buildroot}%{_libexecdir}/ipsec/cavp -v1psk ikev1_psk.fax | \
    diff -u ikev1_psk.fax - > /dev/null
: CAVS tests passed
%endif

%post
%systemd_post ipsec.service

%preun
%systemd_preun ipsec.service

%postun
%systemd_postun_with_restart ipsec.service

%files
%doc CHANGES COPYING CREDITS README* LICENSE
%doc docs/*.* docs/examples
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/ipsec.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/ipsec.secrets
%attr(0700,root,root) %dir %{_sysconfdir}/ipsec.d
%attr(0700,root,root) %dir %{_sysconfdir}/ipsec.d/policies
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/ipsec.d/policies/*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysctl.d/50-libreswan.conf
%attr(0700,root,root) %dir %{_localstatedir}/log/pluto
%attr(0700,root,root) %dir %{_localstatedir}/log/pluto/peer
%attr(0644,root,root) %{_tmpfilesdir}/libreswan.conf
%attr(0644,root,root) %{_unitdir}/ipsec.service
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/pam.d/pluto
%attr(0700,root,root) %dir %{_sharedstatedir}/ipsec/nss
%{_sysconfdir}/logrotate.d/%{name}
%{_sbindir}/ipsec
%{_libexecdir}/ipsec
%doc %{_mandir}/*/*



%changelog
* Wed Feb 03 2021 kekepower <kekepower> 4.2-1.mga8
+ Revision: 1674599
- Update to version 4.2

* Wed Dec 30 2020 luigiwalser <luigiwalser> 4.1-3.mga8
+ Revision: 1665629
- fix l2tp connection to Windows VPN server (rhbz#1894381)

* Wed Dec 30 2020 luigiwalser <luigiwalser> 4.1-2.mga8
+ Revision: 1665628
- add missing nss dir (mga#27984)

* Mon Oct 19 2020 kekepower <kekepower> 4.1-1.mga8
+ Revision: 1637160
- Update to version 4.1

* Fri Oct 16 2020 kekepower <kekepower> 4.0-1.mga8
+ Revision: 1636384
- Update to version 4.0

* Tue Oct 13 2020 luigiwalser <luigiwalser> 3.32-2.mga8
+ Revision: 1635516
- add upstream patch via fedora to fix nss incompatibility (mga#26716)

* Tue May 12 2020 kekepower <kekepower> 3.32-1.mga8
+ Revision: 1583352
- Update to version 3.32

* Wed Mar 04 2020 kekepower <kekepower> 3.31-1.mga8
+ Revision: 1553811
- Update to version 3.31

* Sun Feb 16 2020 umeabot <umeabot> 3.29-5.mga8
+ Revision: 1535017
- Mageia 8 Mass Rebuild

* Sun Feb 16 2020 daviddavid <daviddavid> 3.29-4.mga8
+ Revision: 1532023
- rebuild for new libevent 2.1.11

* Tue Oct 08 2019 daviddavid <daviddavid> 3.29-3.mga8
+ Revision: 1450596
- rebuild for new ldns 1.7.1

* Sat Jul 06 2019 kekepower <kekepower> 3.29-2.mga8
+ Revision: 1419208
- Use tmpfilesdir to create /run/pluto
- Update to version 3.29 to fix CVE-2019-10155 (mga#25065)

* Tue Dec 25 2018 kekepower <kekepower> 3.27-4.mga7
+ Revision: 1344867
- Obsoletes openswan-doc

* Sun Dec 02 2018 kekepower <kekepower> 3.27-3.mga7
+ Revision: 1337506
- Fix Requires

* Sun Dec 02 2018 kekepower <kekepower> 3.27-2.mga7
+ Revision: 1337441
- Fix ghost files
- Fix file list
- Fix Release tag
- imported package libreswan

